pub enum RevocationError {
SessionNotFound,
SessionFamilyNotFound,
Failed,
}Expand description
Revocation and logout related errors.
Variants
SessionNotFound
The target session could not be revoked because it does not exist.
SessionFamilyNotFound
The target session family could not be revoked because it does not exist.
Failed
The revocation operation could not be completed.