pub struct SessionRefreshRecord {
pub session_id: SessionId,
pub family_id: SessionFamilyId,
pub expires_at: SystemTime,
pub revoked: bool,
}Expand description
Repository-facing record for the currently active refresh token of a session.
Examples
use std::time::{Duration, SystemTime};
use webgates_sessions::session::{SessionFamilyId, SessionId, SessionRefreshRecord};
let now = SystemTime::UNIX_EPOCH + Duration::from_secs(1_000);
let expires_at = now + Duration::from_secs(3_600);
let refresh = SessionRefreshRecord::new(SessionId::new(), SessionFamilyId::new(), expires_at);
assert!(refresh.is_active_at(now));
assert!(!refresh.is_expired_at(now));
let revoked = refresh.revoked();
assert!(!revoked.is_active_at(now));Fields
session_id: SessionIdSession that owns the refresh token.
family_id: SessionFamilyIdSession family that owns the refresh token.
expires_at: SystemTimeTimestamp when the current refresh token expires.
revoked: boolWhether the refresh token is currently revoked.
Implementations
Sourceimpl SessionRefreshRecord
impl SessionRefreshRecord
Sourcepub fn new(
session_id: SessionId,
family_id: SessionFamilyId,
expires_at: SystemTime,
) -> Self
pub fn new( session_id: SessionId, family_id: SessionFamilyId, expires_at: SystemTime, ) -> Self
Creates a new active refresh-token record.
Sourcepub fn is_active_at(&self, now: SystemTime) -> bool
pub fn is_active_at(&self, now: SystemTime) -> bool
Returns true when the refresh token is active at now.
Sourcepub fn is_expired_at(&self, now: SystemTime) -> bool
pub fn is_expired_at(&self, now: SystemTime) -> bool
Returns true when the refresh token has expired at now.