pub struct SessionIssuer<R, A, G, H> { /* private fields */ }Expand description
Issues new session state and token pairs.
Use this service after successful authentication when you want to create a session-backed login result.
Examples
use webgates_sessions::config::SessionConfig;
use webgates_sessions::services::SessionIssuer;
use webgates_sessions::tokens::{
OpaqueRefreshTokenGenerator, RefreshTokenLength, Sha256RefreshTokenHasher,
TokenPairIssuer, AuthToken, AuthTokenIssuer,
};
use webgates_sessions::session::Session;
#[derive(Debug, Clone, Copy)]
struct NoopIssuer;
impl AuthTokenIssuer<Session> for NoopIssuer {
type Error = webgates_sessions::errors::TokenError;
fn issue_auth_token(
&self,
s: &Session,
) -> impl std::future::Future<Output = Result<AuthToken, Self::Error>> + Send {
std::future::ready(AuthToken::new(format!("auth-{}", s.subject_id)))
}
}
let length = RefreshTokenLength::new(64).unwrap();
let token_pair_issuer = TokenPairIssuer::new(
NoopIssuer,
OpaqueRefreshTokenGenerator::new(length),
Sha256RefreshTokenHasher,
);
let issuer = SessionIssuer::new(
SessionConfig::default(),
Noop,
token_pair_issuer,
)
.unwrap();Implementations
Sourceimpl<R, A, G, H> SessionIssuer<R, A, G, H>
impl<R, A, G, H> SessionIssuer<R, A, G, H>
Sourcepub fn new(
config: SessionConfig,
repository: R,
token_pair_issuer: TokenPairIssuer<A, G, H>,
) -> ConfigResult<Self>
pub fn new( config: SessionConfig, repository: R, token_pair_issuer: TokenPairIssuer<A, G, H>, ) -> ConfigResult<Self>
Creates a new session issuer from validated configuration, a repository, and a token-pair issuer.
Errors
Returns a configuration error when config is internally inconsistent.
Sourceimpl<R, A, G, H> SessionIssuer<R, A, G, H>where
R: SessionRepository,
A: AuthTokenIssuer<Session>,
G: RefreshTokenGenerator,
H: RefreshTokenHasher,
impl<R, A, G, H> SessionIssuer<R, A, G, H>where
R: SessionRepository,
A: AuthTokenIssuer<Session>,
G: RefreshTokenGenerator,
H: RefreshTokenHasher,
Sourcepub async fn issue_session(
&self,
subject_id: impl Into<String>,
now: SystemTime,
) -> Result<IssuedSession>
pub async fn issue_session( &self, subject_id: impl Into<String>, now: SystemTime, ) -> Result<IssuedSession>
Issues a new session for subject_id, persists it, and returns the
issued session plus tokens.
Errors
Returns a session error when token issuance or persistence fails.