SessionRefreshRecord

Struct SessionRefreshRecord 

pub struct SessionRefreshRecord {
    pub session_id: SessionId,
    pub family_id: SessionFamilyId,
    pub expires_at: SystemTime,
    pub revoked: bool,
}
Repository-facing record for the currently active refresh token of a session.

Examples

use std::time::{Duration, SystemTime};
use webgates_sessions::session::{SessionFamilyId, SessionId, SessionRefreshRecord};

let now = SystemTime::UNIX_EPOCH + Duration::from_secs(1_000);
let expires_at = now + Duration::from_secs(3_600);
let refresh = SessionRefreshRecord::new(SessionId::new(), SessionFamilyId::new(), expires_at);

assert!(refresh.is_active_at(now));
assert!(!refresh.is_expired_at(now));

let revoked = refresh.revoked();
assert!(!revoked.is_active_at(now));

Fields

session_id: SessionId

Session that owns the refresh token.

family_id: SessionFamilyId

Session family that owns the refresh token.

expires_at: SystemTime

Timestamp when the current refresh token expires.

revoked: bool

Whether the refresh token is currently revoked.

Implementations

Source

impl SessionRefreshRecord

pub fn new( session_id: SessionId, family_id: SessionFamilyId, expires_at: SystemTime, ) -> Self

Creates a new active refresh-token record.

pub fn revoked(self) -> Self

Returns a copy of the refresh-token record marked as revoked.

pub fn is_active_at(&self, now: SystemTime) -> bool

Returns true when the refresh token is active at now.

pub fn is_expired_at(&self, now: SystemTime) -> bool

Returns true when the refresh token has expired at now.