pub struct CodecAuthTokenIssuer<C, F> { /* private fields */ }Expand description
Auth-token issuer backed by a webgates-codecs payload codec.
Callers provide a claims factory so this issuer can stay generic over both the subject type and the encoded claim shape.
Examples
use webgates_codecs::jwt::{JsonWebToken, JwtClaims, RegisteredClaims};
use webgates_sessions::tokens::{AuthTokenIssuer, CodecAuthTokenIssuer};
use serde::{Deserialize, Serialize};
#[derive(Debug, Clone, Serialize, Deserialize)]
struct MyClaims {
sub: String,
}
// Install a crypto provider required by jsonwebtoken before using the codec.
webgates_codecs::jsonwebtoken::crypto::rust_crypto::DEFAULT_PROVIDER
.install_default()
.ok();
let codec = JsonWebToken::<JwtClaims<MyClaims>>::default();
let issuer = CodecAuthTokenIssuer::new(codec, |subject: &String| {
JwtClaims::new(
MyClaims { sub: subject.clone() },
RegisteredClaims::new("my-service", 4_102_444_800),
)
});
let token = issuer.issue_auth_token(&String::from("user-42")).await.unwrap();
assert!(!token.as_str().is_empty());Implementations
Sourceimpl<C, F> CodecAuthTokenIssuer<C, F>
impl<C, F> CodecAuthTokenIssuer<C, F>